Function audit_log
pub unsafe extern "C" fn audit_log<T: GCPluginCallbackHandler>(
ctx: GCCoreCtx,
log: *const c_char,
)Expand description
The callback used by the plugins for audit logging
pub unsafe extern "C" fn audit_log<T: GCPluginCallbackHandler>(
ctx: GCCoreCtx,
log: *const c_char,
)The callback used by the plugins for audit logging