release_datapoint_value

Function release_datapoint_value 

pub unsafe extern "C" fn release_datapoint_value(
    dp_value: GCDatapointValue,
) -> bool
The callback used by the plugins to release datapoints The value passed had to be created by the core.

This function cannot be redirected to the GCPluginCallbackHandler trait, because the interface does not provide a context to the core.